@@ -54,7 +54,7 @@ class CfnNamedQuery(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: aws_cdk.core.Construct, id: str, resource_attributes: typing.Any) -> "CfnNamedQuery":
+    def from_cloud_formation(cls, scope: aws_cdk.core.Construct, id: str, resource_attributes: typing.Any, *, finder: aws_cdk.core.ICfnFinder) -> "CfnNamedQuery":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -62,11 +62,14 @@ class CfnNamedQuery(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type
         :param scope: -
         :param id: -
         :param resource_attributes: -
+        :param finder: The finder interface used to resolve references across the template.
 
         stability
         :stability: experimental
         """
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes])
+        options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
+
+        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
@@ -248,7 +251,7 @@ class CfnWorkGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: aws_cdk.core.Construct, id: str, resource_attributes: typing.Any) -> "CfnWorkGroup":
+    def from_cloud_formation(cls, scope: aws_cdk.core.Construct, id: str, resource_attributes: typing.Any, *, finder: aws_cdk.core.ICfnFinder) -> "CfnWorkGroup":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -256,11 +259,14 @@ class CfnWorkGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
         :param scope: -
         :param id: -
         :param resource_attributes: -
+        :param finder: The finder interface used to resolve references across the template.
 
         stability
         :stability: experimental
         """
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes])
+        options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
+
+        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
